@@ -322,6 +322,11 @@ class DoxygenStructDirective(DoxygenClassLikeDirective):
     kind = "struct"
 
 
+class DoxygenInterfaceDirective(DoxygenClassLikeDirective):
+
+    kind = "interface"
+
+
 class DoxygenContentBlockDirective(BaseDirective):
     """Base class for namespace and group directives which have very similar behaviours"""
 
@@ -573,6 +578,7 @@ class DoxygenDirectiveFactory(object):
         "doxygenfunction": DoxygenFunctionDirective,
         "doxygenstruct": DoxygenStructDirective,
         "doxygenclass": DoxygenClassDirective,
+        "doxygeninterface": DoxygenInterfaceDirective,
         "doxygenvariable": DoxygenVariableDirective,
         "doxygendefine": DoxygenDefineDirective,
         "doxygenenum": DoxygenEnumDirective,
@@ -631,7 +637,9 @@ class DoxygenDirectiveFactory(object):
             app.config.breathe_domain_by_extension,
             app.config.breathe_domain_by_file_pattern,
             app.config.breathe_projects_source,
-            app.config.breathe_build_directory
+            app.config.breathe_build_directory,
+            app.config.breathe_show_define_initializer,
+            app.config.breathe_use_project_refids,
             )
 
 
@@ -794,6 +802,7 @@ def setup(app):
     add_directive('doxygentypedef')
     add_directive('doxygenunion')
     add_directive('doxygenclass')
+    add_directive('doxygeninterface')
     add_directive('doxygenfile')
     add_directive('doxygennamespace')
     add_directive('doxygengroup')
@@ -815,8 +824,10 @@ def setup(app):
     app.add_config_value("breathe_projects_source", {}, True)
     app.add_config_value("breathe_build_directory", '', True)
     app.add_config_value("breathe_default_members", (), True)
+    app.add_config_value("breathe_show_define_initializer", False, 'env')
     app.add_config_value("breathe_implementation_filename_extensions", ['.c', '.cc', '.cpp'], True)
     app.add_config_value("breathe_doxygen_config_options", {}, True)
+    app.add_config_value("breathe_use_project_refids", False, "env")
 
     breathe_css = "breathe.css"
     if (os.path.exists(os.path.join(app.confdir, "_static", breathe_css))):
